Learn R Programming

mgwrsar (version 1.3.2)

int_prems: Reorder Intercept Column First

Description

Identifies the intercept column (constant column) in a matrix and moves it to the first position.

Usage

int_prems(X)

Value

The matrix X with the intercept column moved to the first position. If no intercept is found, returns X unchanged.

Arguments

X

A numeric matrix, typically the design matrix.