Learn R Programming

mgwrsar (version 1.3.1)

mgwrsar_bootstrap_test_all: A bootstrap test for testing nullity of all Betas for mgwrsar class model,

Description

A bootstrap test for testing nullity of all Betas for mgwrsar class model,

Usage

mgwrsar_bootstrap_test_all(model,B=100,ncore=1,type='standard')

Value

a matrix with statistical test values and p ratios

Arguments

model

A mgwrsar model

B

number of bootstrap replications, default 100

ncore

number of cores for parallelization.

type

type of boostrap ('spatial','wild','random')

See Also

mgwrsar_bootstrap_test