Learn R Programming

mgwrsar (version 1.3.2)

summary_Matrix: Summary of a Sparse Matrix

Description

Produces a summary of a sparse matrix object showing its non-zero elements in triplet form (row, column, value).

Usage

summary_Matrix(object, ...)

Value

A data frame with columns i, j, x representing the row indices, column indices, and values of non-zero elements.

Arguments

object

A sparse matrix object (inheriting from Matrix).

...

Additional arguments (currently unused).