- H
A vector of bandwidths
- kernels
A vector of kernel types
- coords
A matrix with variables used in kernel (reference)
- NN
Number of spatial Neighbours for kernels computations
- TP
A vector with index of target points
- Type
Type of Genelarized kernel product ('GD' only spatial,'GDC'
spatial + a categorical variable,'GDX' spatial + a continuous variable,
'GDT' spatial + a time index, and other combinations 'GDXXC','GDTX',...)
- adaptive
A vector of boolean to choose adaptive version for each kernel
- diagnull
Zero on diagonal, default FALSE
- alpha
Numeric exponent for the generalized kernel product, default 1.
- dists
A precomputed list of distance matrices (output of prep_d), default NULL.
- indexG
A precomputed matrix of neighbor indices (output of prep_d), default NULL.
- extrapol
Logical. If TRUE, compute weights for extrapolation (out-of-sample), default FALSE.
- QP
A matrix with variables used in kernel (neighbors), default NULL (if NULL coord_j=coord_i).
- K
Integer, number of folds for block computation, default 0 (no blocking).