Internal functions used by the mgwrsar package. These functions are exported for technical reasons but are not intended to be called directly by the typical user.
INST_C(A, B, C, D)
PhWY_C(A, B, C, D)
Proj_C(A, B)
QRcpp2_C(A, B, C)
Sl_C(A, B, C, D)
gwr_beta_pivotal_qrp_cpp(X, y, XV, indexG, Wd, TP, get_ts = FALSE,
get_s = FALSE,get_Rk = FALSE, get_se = FALSE)
gwr_beta_univar_cpp(y, x, XV, indexG, Wd, TP, get_ts = FALSE, get_s = FALSE,
get_se = FALSE)
mgwr_beta_pivotal_qrp_mixed_cpp(XV, y, XC, indexG, Wd, TP, get_ts = FALSE,
get_s = FALSE, get_Rk = FALSE, get_se = FALSE)ApproxiW(W, TP, n)
mod(Y, X, W, X_s, Y_s, S, type, b2sls, get_ts, get_s)
get_index_mahalanobis_dual_rcpp(DS, DTM)
Internal arguments.