powered by
Row-normalizes a sparse matrix (dgCMatrix) or dense matrix so that each row sums to 1. Rows with zero sums are left unchanged.
normW(x)
A row-normalized matrix of the same class as the input.
A matrix or dgCMatrix class sparse matrix.