powered by
Reorders the elements of a distance matrix row by row according to a corresponding index matrix.
reord_D(M, idxG)
A reordered numeric matrix with the same number of rows as `M` and columns equal to the maximum index in `idxG`.
A numeric matrix to be reordered.
An integer matrix of the same number of rows as `M`, where each row contains column indices indicating the new ordering for that row.