powered by
Produces a summary of a sparse matrix object showing its non-zero elements in triplet form (row, column, value).
summary_Matrix(object, ...)
A data frame with columns i, j, x representing the row indices, column indices, and values of non-zero elements.
i
j
x
A sparse matrix object (inheriting from Matrix).
Matrix
Additional arguments (currently unused).